"""
Logging configuration module
"""

from logging.config import dictConfig

FORMATTERS = {
    'verbose': {
        'format': '%(asctime)s - %(name)s - %(levelname)s - %(message)s'
    },

    'simple': {
        'format': '%(levelname)s %(message)s'
    },
}

HANDLERS = {
    'console': {
        'level': 'DEBUG',
        'class': 'logging.StreamHandler',
        'formatter': 'verbose'
    },
}

LOGGERS = {
    'flask': {'handlers': ['console'], 'level': 'INFO', 'propagate': True},
    'flask_restplus': {'handlers': ['console'], 'level': 'INFO', 'propagate': True},
    'portal': {'handlers': ['console'], 'level': 'DEBUG', 'propagate': True},
    'tests': {'handlers': ['console'], 'level': 'DEBUG', 'propagate': True},
    'management': {'handlers': ['console'], 'level': 'INFO', 'propagate': True},
    'app': {'handlers': ['console'], 'level': 'INFO', 'propagate': True},
    'storage': {'handlers': ['console'], 'level': 'INFO', 'propagate': True},
}

LOGGING_CONF = {
    'version': 1,
    'disable_existing_loggers': True,
    'formatters': FORMATTERS,
    'handlers': HANDLERS,
    'loggers': LOGGERS,
}


def load_config(conf_type=None):
    """Loads config based on the config type
    Args:
        conf_type(str): Config type available (dev, test, prod)

    """
    if conf_type is not None:
        print("Not implemented yet!")
    dictConfig(LOGGING_CONF)
