from flask_jwt_extended import jwt_required
from flask_restplus import Namespace, Resource

from portal.rest import rest_helpers
from portal.rest.schemas import notification_schema, submission_result_schema
from portal.service import auth, general, permissions
from portal.service.errors import ForbiddenError
from portal.service.notifications import send_notification, send_submission_result_message

notifications_namespace = Namespace('notifications')


@notifications_namespace.route('/<string:notification_type>')
@notifications_namespace.param('notification_type', 'Notification type')
class NotificationResource(Resource):

    @jwt_required
    @notifications_namespace.response(403, 'Not allowed to send notifications')
    @notifications_namespace.response(200, 'Notification sent')
    def post(self, notification_type: str):
        client = auth.find_client()

        if not (permissions.check_sysadmin(client) or
                permissions.check_component(component=client)):
            raise ForbiddenError(uid=client.id)

        data = rest_helpers.parse_request_data(
            notification_schema, action='update', resource='project'
        )

        send_notification(data, notification_type=notification_type)
        return {'message': 'Notification sent!'}, 200


@notifications_namespace.route('/submissions/<string:sid>')
@notifications_namespace.param('sid', 'Submissions id')
class SubmissionResultResource(Resource):

    @jwt_required
    @notifications_namespace.response(403, 'Not allowed to send notifications')
    @notifications_namespace.response(200, 'Notification sent')
    def post(self, sid: str):
        client = auth.find_client()

        if not (permissions.check_sysadmin(client) or
                permissions.check_component(component=client)):
            raise ForbiddenError(uid=client.id)

        data = rest_helpers.parse_request_data(
            submission_result_schema, action='update', resource='project'
        )

        submission = general.find_submission(sid)
        send_submission_result_message(submission=submission, data=data)
        return {'message': 'Notification sent!'}, 200
