"""
Reviews service
"""

import logging
from typing import List

from portal.database.models import Review, User, ReviewItem, Submission
from portal.service.general import write_entity

log = logging.getLogger(__name__)


def create_review_items(review: Review, author: User,
                        items: List[dict]) -> Review:
    """Creates review items for the review

    Args:
        review(Review): Review instance
        author(User): Review's author
        items(List[dict]): Review items to append to the review

    Returns(Review): review instance with review items
    """
    for item in items:
        ReviewItem(user=author, review=review, file=item['file'], line=item['line'],
                   content=item['content'])
    log.info(f"Added review items {items} to review {review.id} "
             f"for submission {review.submission.id}")
    write_entity(review)
    return review


def create_review(submission: Submission) -> Review:
    """Creates instance of the review

    Args:
        submission(Submission): Submission instance

    Returns(Review): Review instance
    """
    log.debug(f"[CREATE] Review for submission: {submission.id}")
    r = Review(submission=submission)
    write_entity(r)
    return r
